@@ -289,6 +289,7 @@ xkb_new(XfcePanelPlugin *plugin)
   t_xkb *xkb;
   gchar *filename;
   char *initial_group;
+  NetkScreen* netk_screen;
 
   xkb = g_new(t_xkb, 1);
   filename = xfce_panel_plugin_save_location(plugin, TRUE);
@@ -299,10 +300,6 @@ xkb_new(XfcePanelPlugin *plugin)
 
   xkb->size = xfce_panel_plugin_get_size(plugin);
 
-  xkb->display_type = IMAGE;
-  xkb->enable_perapp = TRUE;
-  xkb->default_group = 0;
-
   xkb->plugin = plugin;
 
   xkb->btn = gtk_button_new();
@@ -335,7 +332,7 @@ xkb_new(XfcePanelPlugin *plugin)
       (GIOFunc) &gio_callback, (gpointer) xkb);
 
   /* track signals about window change */
-  NetkScreen* netk_screen = netk_screen_get_default ();
+  netk_screen = netk_screen_get_default ();
   win_change_hanler = g_signal_connect( G_OBJECT (netk_screen), 
       "active_window_changed", G_CALLBACK(active_window_changed), xkb);
 
@@ -441,7 +438,7 @@ xkb_options_dlg_create()
   gtk_box_pack_start(GTK_BOX(hbox), dlg->display_type_optmenu, TRUE, TRUE, 2);
 
   per_app_frame = gtk_frame_new (NULL);
-  gtk_frame_set_label (GTK_FRAME (per_app_frame), _("Per applcation settings"));
+  gtk_frame_set_label (GTK_FRAME (per_app_frame), _("Per application settings"));
   gtk_widget_show (per_app_frame);
   gtk_box_pack_start (GTK_BOX (vbox), per_app_frame, TRUE, TRUE, 2);
   gtk_container_set_border_width (GTK_CONTAINER (per_app_frame), 5);
